<?php

/**
 * About Section
 *
 * @package Charity_Elite
 */

$wp_customize->add_section(
	'charity_elite_about_section',
	array(
		'panel'    => 'charity_elite_front_page_options',
		'title'    => esc_html__( 'About Us Section', 'charity-elite' ),
		'priority' => 20,
	)
);

// About Section - Enable Section.
$wp_customize->add_setting(
	'charity_elite_enable_about_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'charity_elite_sanitize_switch',
	)
);

$wp_customize->add_control(
	new Charity_Elite_Toggle_Switch_Custom_Control(
		$wp_customize,
		'charity_elite_enable_about_section',
		array(
			'label'    => esc_html__( 'Enable About Section', 'charity-elite' ),
			'section'  => 'charity_elite_about_section',
			'settings' => 'charity_elite_enable_about_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'charity_elite_enable_about_section',
		array(
			'selector' => '#charity_elite_about_section .section-link',
			'settings' => 'charity_elite_enable_about_section',
		)
	);
}

// About Section - Content Type.
$wp_customize->add_setting(
	'charity_elite_about_content_type',
	array(
		'default'           => 'page',
		'sanitize_callback' => 'charity_elite_sanitize_select',
	)
);

$wp_customize->add_control(
	'charity_elite_about_content_type',
	array(
		'label'           => esc_html__( 'Select Content Type', 'charity-elite' ),
		'section'         => 'charity_elite_about_section',
		'settings'        => 'charity_elite_about_content_type',
		'type'            => 'select',
		'active_callback' => 'charity_elite_is_about_section_enabled',
		'choices'         => array(
			'page' => esc_html__( 'Page', 'charity-elite' ),
			'post' => esc_html__( 'Post', 'charity-elite' ),
		),
	)
);

// About Section - Content Type Post.
$wp_customize->add_setting(
	'charity_elite_about_content_post',
	array(
		'sanitize_callback' => 'absint',
	)
);

$wp_customize->add_control(
	'charity_elite_about_content_post',
	array(
		'section'         => 'charity_elite_about_section',
		'settings'        => 'charity_elite_about_content_post',
		'label'           => esc_html__( 'Select Post', 'charity-elite' ),
		'active_callback' => 'charity_elite_is_about_section_and_content_type_post_enabled',
		'type'            => 'select',
		'choices'         => charity_elite_get_post_choices(),
	)
);

// About Section - Content Type Page.
$wp_customize->add_setting(
	'charity_elite_about_content_page',
	array(
		'sanitize_callback' => 'absint',
	)
);

$wp_customize->add_control(
	'charity_elite_about_content_page',
	array(
		'label'           => esc_html__( 'Select Page', 'charity-elite' ),
		'section'         => 'charity_elite_about_section',
		'settings'        => 'charity_elite_about_content_page',
		'active_callback' => 'charity_elite_is_about_section_and_content_type_page_enabled',
		'type'            => 'select',
		'choices'         => charity_elite_get_page_choices(),
	)
);

// About Section - Section Text.
$wp_customize->add_setting(
	'charity_elite_about_section_text',
	array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'charity_elite_about_section_text',
	array(
		'label'           => esc_html__( 'About Text', 'charity-elite' ),
		'section'         => 'charity_elite_about_section',
		'settings'        => 'charity_elite_about_section_text',
		'type'            => 'text',
		'active_callback' => 'charity_elite_is_about_section_enabled',
	)
);

// About Section - Button Label.
$wp_customize->add_setting(
	'charity_elite_about_button_label',
	array(
		'default'           => __( 'Read More', 'charity-elite' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'charity_elite_about_button_label',
	array(
		'label'           => esc_html__( 'Button Label', 'charity-elite' ),
		'section'         => 'charity_elite_about_section',
		'settings'        => 'charity_elite_about_button_label',
		'type'            => 'text',
		'active_callback' => 'charity_elite_is_about_section_enabled',
	)
);

// About Section - Video Label.
$wp_customize->add_setting(
	'charity_elite_about_video_label',
	array(
		'default'           => __( 'Play Video', 'charity-elite' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'charity_elite_about_video_label',
	array(
		'label'           => esc_html__( 'Video Label', 'charity-elite' ),
		'description'     => esc_html__( 'If the video link field is empty then it will not show video label in front section.', 'charity-elite' ),
		'section'         => 'charity_elite_about_section',
		'settings'        => 'charity_elite_about_video_label',
		'type'            => 'text',
		'active_callback' => 'charity_elite_is_about_section_enabled',
	)
);

// About Section - Video Link.
$wp_customize->add_setting(
	'charity_elite_about_video_link',
	array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control(
	'charity_elite_about_video_link',
	array(
		'label'           => esc_html__( 'Video Link', 'charity-elite' ),
		'section'         => 'charity_elite_about_section',
		'settings'        => 'charity_elite_about_video_link',
		'type'            => 'url',
		'active_callback' => 'charity_elite_is_about_section_enabled',
	)
);
